@@ -48,6 +48,7 @@
 
 int NumLockMask, CapsLockMask, ScrollLockMask;
 
+gboolean gail_loaded = FALSE;
 GtkWidget *bah_window = NULL;
 
 gchar *
@@ -66,13 +67,6 @@ event_filter (GdkXEvent * gdk_xevent, GdkEvent * event, gpointer data);
 
 static void gkb_destroy (GtkWidget * widget, gpointer data);
 
-static void
-set_tooltip (GtkWidget * w, const gchar * tip)
-{
-  GtkTooltips *t = gtk_tooltips_new ();
-  gtk_tooltips_set_tip (t, w, tip, NULL);
-}
-
 void alert(const gchar * str){
  GtkWidget * window;
  window = gnome_message_box_new (str,
@@ -116,7 +110,8 @@ gkb_draw (GKB * gkb)
       gtk_label_set_text (GTK_LABEL (gkb->label2), gkb->keymap->label);
     }
 
-  set_tooltip (gkb->applet, gkb->keymap->name);
+  gtk_tooltips_set_tip (gkb->tooltips, gkb->applet, gkb->keymap->name, NULL);
+  add_atk_namedesc(gkb->applet, gkb->keymap->name, _("Press the hotkey to switch between layouts. The hotkey can be set through Properties dialog"));
 
 }
 
@@ -275,12 +270,16 @@ gkb_sized_render (GKB * gkb)
       real_name = gnome_unconditional_pixmap_file (name);
       if (g_file_exists (real_name))
 	{
+	  if (keymap->pixbuf) 
+	    g_object_unref (keymap->pixbuf);
 	  keymap->pixbuf = gdk_pixbuf_new_from_file (real_name,NULL);
 	}
       else
 	{
 	  g_free (real_name);
 	  real_name = gnome_unconditional_pixmap_file ("gkb/gkb-foot.png");
+	  if (keymap->pixbuf)
+	    g_object_unref (keymap->pixbuf);
 	  keymap->pixbuf = gdk_pixbuf_new_from_file (real_name,NULL);
 	}
       g_free (name);
@@ -350,11 +349,11 @@ applet_save_session ()
   gchar str[100];
   int i = 0;
 
-  panel_applet_gconf_set_int (PANEL_APPLET (gkb->applet), "num", gkb->n, NULL);
-  panel_applet_gconf_set_bool (PANEL_APPLET (gkb->applet), "small", gkb->is_small, NULL);
-  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), "key", gkb->key, NULL);
+  gconf_applet_set_int (PANEL_APPLET (gkb->applet), "num", gkb->n, NULL);
+  gconf_applet_set_bool (PANEL_APPLET (gkb->applet), "small", gkb->is_small, NULL);
+  gconf_applet_set_string (PANEL_APPLET (gkb->applet), "key", gkb->key, NULL);
   text = gkb_util_get_text_from_mode (gkb->mode);
-  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), "mode", text, NULL);
+  gconf_applet_set_string (PANEL_APPLET (gkb->applet), "mode", text, NULL);
 
   while (list)
     {
@@ -362,17 +361,17 @@ applet_save_session ()
       if (actdata)
 	{
 	  g_snprintf (str, sizeof (str), "name_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->name, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->name, NULL);
 	  g_snprintf (str, sizeof (str), "country_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->country, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->country, NULL);
 	  g_snprintf (str, sizeof (str), "lang_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->lang, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->lang, NULL);
 	  g_snprintf (str, sizeof (str), "label_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->label, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->label, NULL);
 	  g_snprintf (str, sizeof (str), "flag_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->flag, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->flag, NULL);
 	  g_snprintf (str, sizeof (str), "command_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->command, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->command, NULL);
 	}
 
       list = list->next;
@@ -386,7 +385,7 @@ gkb_load_pref(const gchar * key, const gchar * defaultv)
 {
  gchar * value;
 
- value = panel_applet_gconf_get_string (PANEL_APPLET(gkb->applet), key, NULL);
+ value = gconf_applet_get_string (PANEL_APPLET(gkb->applet), key, NULL);
  
  if (value == NULL) {
   value = g_strdup (defaultv);
@@ -404,22 +403,26 @@ loadprop (int i)
 
   buf = g_strdup_printf (_("name_%d"),i);
   actdata->name = gkb_load_pref (buf, (i?"Hungarian 105 keys keyboard":"US 105 key keyboard"));
+  g_free (buf);
 
   buf = g_strdup_printf (_("label_%d"), i);
   actdata->label = gkb_load_pref (buf, (i?"hu":"us"));
-
+  g_free (buf);
+  
   buf = g_strdup_printf (_("country_%d"), i);
   actdata->country = gkb_load_pref (buf, (i?"Hungary":"United States"));
-
+  g_free (buf);
+  
   buf = g_strdup_printf (_("lang_%d"), i);
   actdata->lang = gkb_load_pref (buf, (i?"Hungarian":"English"));
-
+  g_free (buf);
+  
   buf = g_strdup_printf (("flag_%d"), i);
   actdata->flag = gkb_load_pref (buf, (i?"hu.png":"us.png"));
-
+  g_free (buf);
+  
   buf = g_strdup_printf (_("command_%d"), i);
   actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap hu":"gkb_xmmap us"));
-
   g_free(buf);
 
   actdata->pixbuf = NULL;
@@ -437,12 +440,12 @@ load_properties (GKB * gkb)
 
   gkb->maps = NULL;
 
-  gkb->n = panel_applet_gconf_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
+  gkb->n = gconf_applet_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
 
   gkb->key = gkb_load_pref ("key", "Mod1-Shift_L");
   convert_string_to_keysym_state (gkb->key, &gkb->keysym, &gkb->state);
 
-  gkb->is_small = panel_applet_gconf_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
+  gkb->is_small = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
 #ifdef THIS_IS_UNNECESSARY
   if (gkb->is_small == NULL) {
     gkb->is_small = TRUE;
@@ -534,6 +537,8 @@ create_gkb_widget ()
   gtk_frame_set_shadow_type (GTK_FRAME (gkb->label_frame2), GTK_SHADOW_IN);
   gtk_container_add (GTK_CONTAINER (gkb->label_frame2), gkb->label2);
   gtk_container_add (GTK_CONTAINER (gkb->hbox), gkb->label_frame2);
+  
+  gkb->tooltips = gtk_tooltips_new ();
 
 }
 
@@ -546,6 +551,7 @@ about_cb (BonoboUIComponent *uic,
   GtkWidget *link;
   gchar *file;	
   GdkPixbuf *pixbuf;
+  GError    *error = NULL;
 
   static const gchar *authors[] = {
 	        "Szabolcs Ban <shooby@gnome.hu>",
@@ -559,21 +565,24 @@ about_cb (BonoboUIComponent *uic,
 	        "Szabolcs Ban <shooby@gnome.hu>",
 		NULL
 	};
-	
 
-  pixbuf = NULL;
-  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gkb-icon.png", TRUE, NULL);
-  if (!file) {
-         g_warning (G_STRLOC ": gkb-icon.png cannot be found");
-         pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+  const gchar *translator_credits = _("translator_credits");
+
+  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gkb-icon.png", FALSE, NULL);
+  pixbuf = gdk_pixbuf_new_from_file (file, &error);
+  g_free (file);
+
+  if (error) {
+         g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+         g_error_free (error);
   }
 
-  about = gnome_about_new (_("The GNOME KeyBoard Switcher Applet"),
+  about = gnome_about_new (_("Keyboard Layout Switcher"),
 			   VERSION,
 			   _("(C) 1998-2000 Free Software Foundation"),
                            _("This applet switches between keyboard maps "
-                             "using setxkbmap, or xmodmap.\n"
-                             "Mail me your flag and keyboard layout"
+                             "using setxkbmap or xmodmap.\n"
+                             "Mail me your flag and keyboard layout "
                              "if you want support for your locale "
                              "(my email address is shooby@gnome.hu).\n"
                              "So long, and thanks for all the fish.\n"
@@ -584,7 +593,7 @@ about_cb (BonoboUIComponent *uic,
                               "\nShooby Ban <shooby@gnome.hu>"),
                             authors,
 			    docauthors,
-			    NULL,
+			    strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			    pixbuf);
 
   link = gnome_href_new ("http://projects.gnome.hu/gkb",
@@ -593,13 +602,11 @@ about_cb (BonoboUIComponent *uic,
   gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox), link, TRUE,
 		      FALSE, 0);
 
-  gtk_window_set_wmclass (GTK_WINDOW (about), "gkb", "Gkb");
-
-  if (pixbuf) {
-                gtk_window_set_icon (GTK_WINDOW (about), pixbuf);
-                g_object_unref (pixbuf);
-  }
+  if (pixbuf)
+  	g_object_unref (pixbuf);
 
+  gtk_window_set_wmclass (GTK_WINDOW (about), "keyboard layout switcher", "Keyboard Layout Switcher");
+  gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gkb.png");
   g_signal_connect (G_OBJECT(about), "destroy",
                           (GCallback)gtk_widget_destroyed, &about);
 
@@ -804,7 +811,10 @@ gkb_factory (PanelApplet *applet,
 		gpointer     data)
 {
  	gboolean retval = FALSE;
-
+	if ( GTK_IS_ACCESSIBLE(gtk_widget_get_accessible(GTK_WIDGET(applet))))
+	  {
+            gail_loaded = TRUE;
+          }
         if (!strcmp (iid, "OAFIID:GNOME_KeyboardApplet"))
 		retval = fill_gkb_applet (applet);
 
@@ -817,3 +827,37 @@ PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_KeyboardApplet_Factory",
                              "0",
                              gkb_factory,
                              NULL)
+
+/* Add AtkRelation */                                                           
+void                                                                            
+add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType rel_type)
+{
+    AtkObject *atk_obj1, *atk_obj2;
+    AtkRelationSet *relation_set;
+    AtkRelation *relation;
+
+    atk_obj1 = gtk_widget_get_accessible(obj1);
+
+    atk_obj2 = gtk_widget_get_accessible(obj2);
+
+    relation_set = atk_object_ref_relation_set (atk_obj1);
+    relation = atk_relation_new(&atk_obj2, 1, rel_type);
+    atk_relation_set_add(relation_set, relation);
+    g_object_unref(G_OBJECT (relation));
+}
+
+/* Accessible name and description */                                           
+void                                                                            
+add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc)       
+{                                                                               
+    AtkObject *atk_widget;                                                      
+    atk_widget = gtk_widget_get_accessible(widget);                             
+    if (name)                                                                   
+    {                                                                           
+      atk_object_set_name(atk_widget, name);                                    
+    }                                                                           
+    if (desc)                                                                   
+    {                                                                           
+      atk_object_set_description(atk_widget, desc);                             
+    }                                                                           
+}                                                                               
