@@ -30,6 +30,10 @@
  * USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <gdk/gdkx.h>
 #include <sys/stat.h>
 #include <X11/Xlib.h>
@@ -295,14 +299,14 @@ gkb_prop_create_display_frame (GkbPropertyBoxInfo * pbi)
   gtk_table_set_row_spacings (GTK_TABLE (table), 15);
 
   /* Labels and option Menus */
-  gkb_prop_label_at (table, 0, 0, _("_Appearance "));
+  gkb_prop_label_at (table, 0, 0, _("_Appearance: "));
   mode = gkb_prop_get_mode ();
   gkb_prop_option_menu_at (table, 1, 0, mode,
 			   GTK_SIGNAL_FUNC (gkb_prop_mode_changed), pbi,
 			   gkb_util_get_int_from_mode (pbi->mode));
   g_list_free (mode);
   
-  gkb_prop_label_at (table, 0, 1, _("Applet _size "));
+  gkb_prop_label_at (table, 0, 1, _("Applet _size: "));
   sizes = gkb_prop_get_sizes ();
   gkb_prop_option_menu_at (table, 1, 1, sizes,
 			   GTK_SIGNAL_FUNC (gkb_prop_size_changed),
@@ -379,7 +383,8 @@ window_response (GtkWidget *w, int response, gpointer data)
   if (response == GTK_RESPONSE_HELP)
     prophelp_cb (gkb->applet, data);
   else {
-    gtk_list_clear_items (pbi->list, 0, -1);
+    gtk_list_store_clear (GTK_LIST_STORE (gtk_tree_view_get_model 
+                          (GTK_TREE_VIEW (pbi->list))));
     g_free (pbi);
     gtk_widget_destroy (w);
   }
@@ -402,7 +407,7 @@ gkb_prop_create_property_box (GkbPropertyBoxInfo * pbi)
   GtkWidget *page_2_label;
 
   /* Create property box */
-  propwindow = gtk_dialog_new_with_buttons (_("GKB Properties"), NULL,
+  propwindow = gtk_dialog_new_with_buttons (_("Keyboard Layout Switcher Preferences"), NULL,
                                             GTK_DIALOG_DESTROY_WITH_PARENT,
                                             GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                             NULL);
@@ -459,7 +464,8 @@ gkb_prop_box_destroy (GtkWidget * box, GkbPropertyBoxInfo * pbi)
    * row, so we need to clear the selection so that the
    * gkb_prop_list_selection_changed function is not reached.
    * if you know of a way to solve this, enlighten me. Chema */
-  gtk_list_clear_items (pbi->list, 0, -1);
+  gtk_list_store_clear (GTK_LIST_STORE (gtk_tree_view_get_model 
+                        (GTK_TREE_VIEW (pbi->list))));
   g_free (pbi);
 
   return FALSE;
