@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.36 2002/02/23 22:05:36 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.45 2002/03/23 17:26:34 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -29,54 +29,45 @@
 #include "gweather-dialog.h"
 #include "gweather-applet.h"
 
-/* this may wreak havoc with the bonobo control+gconf stuff, but it's the only way i can see to do it */
-static GWeatherApplet *evil_global_applet;
-
 /* FIX - This code is WAY too kludgy!... */
 static void place_widgets (GWeatherApplet *gw_applet)
 {
-    GtkRequisition pix_requisition;
-    GtkRequisition lbl_requisition;
-
-    gint size;
-/*
-    g_return_if_fail(frame != NULL);
-    g_return_if_fail(fixed != NULL);
-    g_return_if_fail(pixmap != NULL);
-    g_return_if_fail(label != NULL);
-*/
-
-	size = gw_applet->size;
-
-    gtk_widget_get_child_requisition(gw_applet->label, &lbl_requisition);
-    gtk_widget_get_child_requisition(gw_applet->pixmap, &pix_requisition);
-
-    if (((gw_applet->orient == PANEL_APPLET_ORIENT_LEFT) || (gw_applet->orient == PANEL_APPLET_ORIENT_RIGHT)) ^ (size < 25)) {
-        gint sep = MAX(0, (size - pix_requisition.width - lbl_requisition.width) / 3);
-        gint lbl_x = sep + pix_requisition.width + sep;
-        if (lbl_x + lbl_requisition.width > size) {
-            lbl_x = size + 2;
-            sep = MAX(0, (size - pix_requisition.width) / 2);
-        }
-
-        gtk_widget_set_size_request(gw_applet->frame, MAX (size, 48), 24);
-        gtk_fixed_move(GTK_FIXED(gw_applet->fixed), gw_applet->pixmap, sep, 2);
-        gtk_fixed_move(GTK_FIXED(gw_applet->fixed), gw_applet->label, lbl_x, 2);
-    } else {
-        gint panel_width = MAX(lbl_requisition.width, 22);
-        gint sep = MAX(0, (size - pix_requisition.height - lbl_requisition.height) / 3);
-        gint lbl_y = sep + pix_requisition.height + sep;
-        if (lbl_y + lbl_requisition.height > size) {
-            lbl_y = size + 2;
-            sep = MAX(0, (size - pix_requisition.height) / 2);
-        }
-
-        gtk_widget_set_size_request(gw_applet->frame, 24, size);
-        gtk_fixed_move(GTK_FIXED(gw_applet->fixed), gw_applet->pixmap, (panel_width - pix_requisition.width) / 2 - 1, sep);
-        gtk_fixed_move(GTK_FIXED(gw_applet->fixed), gw_applet->label, (panel_width - lbl_requisition.width) / 2, lbl_y);
+    gint size = gw_applet->size;
+    const gchar *temp;
+ 
+    if (gw_applet->box)
+        gtk_widget_destroy (gw_applet->box);
+    
+    if (((gw_applet->orient == PANEL_APPLET_ORIENT_LEFT) || 
+         (gw_applet->orient == PANEL_APPLET_ORIENT_RIGHT)) ^ (size < 25)) {
+         gw_applet->box = gtk_hbox_new (FALSE, 2);
+         
     }
+    else {
+         gw_applet->box = gtk_vbox_new (FALSE, 2);
+    }
+    
+    gtk_container_add (GTK_CONTAINER (gw_applet->applet), gw_applet->box);
+    
+    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
+    				 &(gw_applet->applet_pixbuf));     
+    gw_applet->image = gtk_image_new_from_pixbuf (gw_applet->applet_pixbuf);
+    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->image, FALSE, FALSE, 0);
+         
+    gw_applet->label = gtk_label_new("0\302\260");
+    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->label, FALSE, FALSE, 0);
+    
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
+    			       gw_applet->applet_pixbuf);
+
+    /* Update temperature text */
+
+    temp = weather_info_get_temp_summary(gw_applet->gweather_info);
+    if (temp)
+    	gtk_label_set_text(GTK_LABEL(gw_applet->label), temp);
+
+    gtk_widget_show_all (GTK_WIDGET (gw_applet->applet));
 
-	return;
 }
 
 static void change_orient_cb (PanelApplet *w, PanelAppletOrient o, gpointer data)
@@ -97,17 +88,20 @@ static void change_size_cb(PanelApplet *w, gint s, gpointer data)
     return;
 }
 
-#ifdef FIXME
-static void clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
+
+static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
 {
+    GWeatherApplet *gw_applet = data;
     if ((ev == NULL) || (ev->button != 1))
-	    return;
-
-    gweather_pref_run ();
-
-    return;
+	    return FALSE;
+    if (ev->type == GDK_2BUTTON_PRESS) {
+	gweather_dialog_open(gw_applet);
+	return TRUE;
+    }
+    
+    return FALSE;
 }
-#endif
+
 static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 
@@ -136,7 +130,7 @@ static void forecast_cb (BonoboUIComponent *uic, gpointer data, const gchar *ver
 {
     GWeatherApplet *gw_applet = data;
 
-    gweather_dialog_display_toggle(gw_applet);
+    gweather_dialog_open(gw_applet);
 
     return;
 }
@@ -163,26 +157,20 @@ static const BonoboUIVerb weather_applet_menu_verbs [] = {
 
 void gweather_applet_create (GWeatherApplet *gw_applet)
 {
-	GtkWidget *frame;
-	GtkWidget *label;
-	GtkWidget *fixed;
-	GtkWidget *pixmap;
-	GtkTooltips *tooltips;
-
+    GtkWidget *label;
+    GtkWidget *pixmap;
+    GtkTooltips *tooltips;
  
-   gw_applet->gweather_pref.location = NULL;
-   gw_applet->gweather_pref.update_interval = 1800;
-   gw_applet->gweather_pref.update_enabled = TRUE;
-   gw_applet->gweather_pref.use_metric = FALSE;
-   gw_applet->gweather_pref.detailed = FALSE;
-   gw_applet->gweather_pref.radar_enabled = TRUE;
-   gw_applet->gweather_pref.proxy_url = NULL;
-   gw_applet->gweather_pref.proxy_user = NULL;
-   gw_applet->gweather_pref.proxy_passwd = NULL;
-   gw_applet->gweather_pref.use_proxy = FALSE;
-   
+    gw_applet->gweather_pref.location = NULL;
+    gw_applet->gweather_pref.update_interval = 1800;
+    gw_applet->gweather_pref.update_enabled = TRUE;
+    gw_applet->gweather_pref.use_metric = FALSE;
+    gw_applet->gweather_pref.detailed = FALSE;
+    gw_applet->gweather_pref.radar_enabled = TRUE;
+    
+#if 0   
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gweather/tstorm.xpm");
-
+#endif
     /* PUSH */
     gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
@@ -196,36 +184,15 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
                        G_CALLBACK(change_orient_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "change_size",
                        G_CALLBACK(change_size_cb), gw_applet);
-/*
-    gtk_signal_connect (GTK_OBJECT(gweather_applet), "button_press_event",
-                       GTK_SIGNAL_FUNC(clicked_cb), NULL);
-*/
+
+    gtk_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
+                       GTK_SIGNAL_FUNC(clicked_cb), gw_applet);
+
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy",
                         G_CALLBACK(gtk_main_quit), NULL);
                         
     tooltips = gtk_tooltips_new();
 
-    frame = gtk_frame_new(NULL);
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE);
-    gtk_widget_set_size_request(frame, 26, 48);
-    gtk_widget_show(frame);
-
-    weather_info_get_pixmap_mini(NULL, &(gw_applet->applet_pixmap), &(gw_applet->applet_mask));
-    pixmap = gtk_pixmap_new(gw_applet->applet_pixmap, gw_applet->applet_mask);
-    gtk_widget_show(pixmap);
-
-    label = gtk_label_new("0\302\260");
-    gtk_widget_show(label);
-
-    fixed = gtk_fixed_new();
-    gtk_widget_show(fixed);
-    gtk_fixed_put(GTK_FIXED(fixed), pixmap, 4, 4);
-    gtk_fixed_put(GTK_FIXED(fixed), label, 2, 26);
-
-    gtk_container_add(GTK_CONTAINER(frame), fixed);
-
-    gtk_container_add(GTK_CONTAINER(gw_applet->applet), frame);
-
     gtk_tooltips_set_tip(tooltips, GTK_WIDGET(gw_applet->applet), _("GNOME Weather"), NULL);
 
     gw_applet->size = panel_applet_get_size (gw_applet->applet);
@@ -239,14 +206,8 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 			               weather_applet_menu_verbs,
 			               gw_applet);
 
-	gw_applet->frame = frame;
-	gw_applet->label = label;
-	gw_applet->fixed = fixed;
-	gw_applet->pixmap = pixmap;
-	gw_applet->tooltips = tooltips;
+    gw_applet->tooltips = tooltips;
 	
-	gtk_widget_show_all(GTK_WIDGET(gw_applet->applet));
-
     place_widgets(gw_applet);
     /* POP */
     gtk_widget_pop_colormap ();
@@ -291,18 +252,18 @@ void gweather_info_load (const gchar *path, GWeatherApplet *gw_applet)
     gnome_config_pop_prefix();
 }
 
-static gint timeout_cb (gpointer data)
+gint timeout_cb (gpointer data)
 {
-	GWeatherApplet *gw_applet = (GWeatherApplet *)data;
+    GWeatherApplet *gw_applet = (GWeatherApplet *)data;
 	
     gweather_update(gw_applet);
     return 0;  /* Do not repeat timeout (will be re-set by gweather_update) */
 }
 
-static void update_finish (WeatherInfo *info)
+void update_finish (WeatherInfo *info)
 {
     char *s;
-    GWeatherApplet *gw_applet =evil_global_applet;
+    GWeatherApplet *gw_applet = info->applet;
     
 /*
     if (info != gweather_info) {
@@ -316,22 +277,20 @@ static void update_finish (WeatherInfo *info)
     }
 */
     /* Store current conditions */
-    /* gweather_info_save(APPLET_WIDGET(gweather_applet)->privcfgpath); */
     
     gw_applet->gweather_info = info;
-
-    /* Update applet pixmap */
-    weather_info_get_pixmap_mini(gw_applet->gweather_info, &(gw_applet->applet_pixmap), &(gw_applet->applet_mask));
-    gtk_pixmap_set(GTK_PIXMAP(gw_applet->pixmap), gw_applet->applet_pixmap, gw_applet->applet_mask);
-
-    /* Update temperature text */
    
-    gtk_label_set_text(GTK_LABEL(gw_applet->label), weather_info_get_temp_summary(gw_applet->gweather_info));
- 
-    /* Resize as necessary */
-    place_widgets(gw_applet);
+    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
+    				 &(gw_applet->applet_pixbuf));
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
+    			       gw_applet->applet_pixbuf);
+
+    if (gw_applet->gweather_pref.use_metric)
+        weather_info_to_metric (gw_applet->gweather_info);
+        
+    gtk_label_set_text(GTK_LABEL(gw_applet->label), 
+    		       weather_info_get_temp_summary(gw_applet->gweather_info));
 
-    /* Update tooltip */
 
     s = weather_info_get_weather_summary(gw_applet->gweather_info);
     gtk_tooltips_set_tip(gw_applet->tooltips, GTK_WIDGET(gw_applet->applet), s, NULL);
@@ -342,8 +301,9 @@ static void update_finish (WeatherInfo *info)
     if (gw_applet->timeout_tag > 0)
         gtk_timeout_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
-        gw_applet->timeout_tag =  gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
-                                        timeout_cb, gw_applet);
+        gw_applet->timeout_tag =  
+        	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
+                                 timeout_cb, gw_applet);
 
     /* Update dialog -- if one is present */
     gweather_dialog_update(gw_applet);
@@ -355,36 +315,34 @@ void gweather_update (GWeatherApplet *gw_applet)
 
     /* Let user know we are updating */
 
-    weather_info_get_pixmap_mini(gw_applet->gweather_info, &(gw_applet->applet_pixmap), &(gw_applet->applet_mask));
+    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
+    				 &(gw_applet->applet_pixbuf));
 
-    gtk_pixmap_set(GTK_PIXMAP(gw_applet->pixmap), gw_applet->applet_pixmap, gw_applet->applet_mask);
-    gtk_tooltips_set_tip(gw_applet->tooltips, GTK_WIDGET(gw_applet->applet), _("Updating..."), NULL);
-
-    /* Set preferred units */
-    weather_units_set(gw_applet->gweather_pref.use_metric ? UNITS_METRIC : UNITS_IMPERIAL);
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
+    			       gw_applet->applet_pixbuf);
+    gtk_tooltips_set_tip(gw_applet->tooltips, GTK_WIDGET(gw_applet->applet), 
+    			 _("Updating..."), NULL);
 
     /* Set preferred forecast type */
-    weather_forecast_set(gw_applet->gweather_pref.detailed ? FORECAST_ZONE : FORECAST_STATE);
+    weather_forecast_set(gw_applet->gweather_pref.detailed ? 
+    			 	FORECAST_ZONE : FORECAST_STATE);
 
     /* Set radar map retrieval option */
     weather_radar_set(gw_applet->gweather_pref.radar_enabled);
 
-    /* Set proxy */
-    if (gw_applet->gweather_pref.use_proxy)
-        weather_proxy_set(gw_applet->gweather_pref.proxy_url, gw_applet->gweather_pref.proxy_user, gw_applet->gweather_pref.proxy_passwd);
-
     /* Update current conditions */
-    if (gw_applet->gweather_info && weather_location_equal(gw_applet->gweather_info->location, gw_applet->gweather_pref.location)) {
-    	evil_global_applet = gw_applet;
-        update_success = weather_info_update(gw_applet->gweather_info, update_finish);
+    if (gw_applet->gweather_info && 
+    	weather_location_equal(gw_applet->gweather_info->location, 
+    			       gw_applet->gweather_pref.location)) {
+        update_success = weather_info_update(gw_applet, 
+        				      gw_applet->gweather_info, 
+        				      update_finish);
     } else {
         weather_info_free(gw_applet->gweather_info);
         gw_applet->gweather_info = NULL;
-        evil_global_applet = gw_applet;
-        update_success = weather_info_new(gw_applet->gweather_pref.location, update_finish);
+        update_success = weather_info_new((gpointer)gw_applet, 
+        		 gw_applet->gweather_pref.location, update_finish);
     }
-    if (!update_success)
-        gnome_error_dialog(_("Update failed! Maybe another update was already in progress?"));  /* FIX */
-
+    
     return;
 }
