@@ -108,6 +108,8 @@ typedef struct {
 	/* The popup window and scale. */
 	GtkWidget         *popup;
 	GtkWidget         *scale;
+
+	GtkTooltips	  *tooltips;
 } MixerData;
 
 static void mixer_update_slider (MixerData *data);
@@ -119,10 +121,15 @@ static void mixer_start_gmix_cb (BonoboUIComponent *uic,
 				 gpointer           data,
 				 const gchar       *verbname);
 
+void add_atk_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
 
 static gint mixerfd = -1;
 static GdkPixbuf *zero_pixbuf = NULL, *min_pixbuf, *medium_pixbuf, *max_pixbuf, *mute_pixbuf;
+static gchar *run_mixer_cmd = NULL;
 
+static const gchar *access_name = N_("Volume Control");     
+static const gchar *access_name_mute = N_("Volume Control (muted)");
+gboolean gail_loaded = FALSE;  
 
 #ifdef OSS_API
 static int mixerchannel;
@@ -142,8 +149,8 @@ long pv_buf[MAX_PV_BUF] = {
 /********************** Mixer related Code *******************/
 /*  Mostly based on the gmix code                            */
 /*************************************************************/
-static void
-openMixer( gchar *device_name ) 
+static gboolean
+openMixer(const gchar *device_name ) 
 {
 	gint res, ver;
 #ifdef OSS_API
@@ -163,13 +170,8 @@ openMixer( gchar *device_name )
 	mixerfd = ALgetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
 #endif
 	if (mixerfd < 0) {
-		/* probably should die more gracefully */
-		char *s = g_strdup_printf(_("Couldn't open mixer device %s\n"),
-					  device_name);
-		gnome_error_dialog(s);
-		g_warning(s);
-		g_free(s);
-		return;
+		/* probably should die more gracefully */		
+		return FALSE;
 	}
 
         /*
@@ -192,7 +194,7 @@ openMixer( gchar *device_name )
 		char *s = g_strdup_printf(_("Querying available channels of mixer device %s failed\n"), device_name);
 		gnome_error_dialog(s);
 		g_free(s);
-		return;
+		return TRUE;
 	} else if (devmask & SOUND_MASK_VOLUME) {
 		mixerchannel = SOUND_MIXER_VOLUME;
 	} else if (devmask & SOUND_MASK_PCM) {
@@ -202,9 +204,10 @@ openMixer( gchar *device_name )
 		char *s = g_strdup_printf(_("Mixer device %s has neither volume nor PCM channels.\n"), device_name);
 		gnome_error_dialog(s);
 		g_free(s);
-		return;
+		return TRUE;
 	}
-#endif		
+#endif	
+ 	return TRUE;	
 }
 
 /* only works with master vol currently */
@@ -308,6 +311,14 @@ mixer_timeout_cb (MixerData *data)
 					      "state",
 					      "0",
 					      NULL);
+		
+		gtk_tooltips_set_tip (data->tooltips,
+				      data->applet,
+				      _(access_name),
+			              NULL); 
+		if (gail_loaded) {
+			add_atk_namedesc (data->applet, _(access_name), NULL);
+		}
 	}
 
 	if (!data->mute && vol != data->vol) {
@@ -404,6 +415,7 @@ scale_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data
 static gboolean
 scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
+
 	if (data->popup != NULL) {
 		mixer_popup_hide (data, FALSE);
 		return TRUE;
@@ -412,38 +424,60 @@ scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerDa
 	return FALSE;
 }
 
-static gboolean
-applet_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
-{
-	if (data->popup != NULL) {
-		mixer_popup_hide (data, FALSE);
-		return TRUE;
-	}
-
-	if (event->button == 1) {
-		gtk_frame_set_shadow_type (GTK_FRAME (data->frame), GTK_SHADOW_IN);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
 static gboolean
 applet_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
 	if (event->button == 1) {
-		mixer_popup_show (data);
-		return TRUE;
+		if (data->popup == NULL) {
+			mixer_popup_show (data);
+			return TRUE;
+		}
 	}
 
-	/* Make sure we don't leave the frame sunken in if button 1 is pressed
-	 * and then another button is released.
-	 */
-	gtk_frame_set_shadow_type (GTK_FRAME (data->frame), GTK_SHADOW_NONE);
+	return FALSE;
+}
+
+static gboolean
+applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data)
+{
+	switch (event->keyval) {
+	case GDK_Escape:
+		/* Revert. */
+		mixer_popup_hide (data, TRUE);
+		return TRUE;
+
+	case GDK_KP_Enter:
+	case GDK_ISO_Enter:
+	case GDK_3270_Enter:
+	case GDK_Return:
+	case GDK_space:
+	case GDK_KP_Space:
+		/* Apply. */
+		if (data->popup != NULL)
+			mixer_popup_hide (data, FALSE);
+		else
+			mixer_popup_show (data);
+		return TRUE;
+
+	default:
+		break;
+	}
 
 	return FALSE;
 }
 
+
+static gboolean
+applet_scroll_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data)
+{
+       if (event->type = GDK_SCROLL) {
+               if (data->popup == NULL)
+                       mixer_popup_show (data);
+               return TRUE;
+       }
+       return FALSE;
+}
+
 static void
 mixer_popup_show (MixerData *data)
 {
@@ -476,7 +510,12 @@ mixer_popup_show (MixerData *data)
 		gtk_widget_set_size_request (data->scale, 100, -1);
 		gtk_range_set_inverted (GTK_RANGE (data->scale), TRUE);
 	}
-
+	
+	if (gail_loaded) {
+		add_atk_namedesc (data->scale, 
+				_("Volume Controller"),
+				_("Use Up/Down arrow keys to change volume"));
+	}
 	g_signal_connect (data->scale,
 			  "button-release-event",
 			  (GCallback) scale_button_release_event_cb,
@@ -622,7 +661,7 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		gtk_timeout_remove (data->timeout);
 		data->timeout = 0;
 	}
-
+	
 	g_free (data);
 }
 
@@ -681,7 +720,15 @@ mixer_start_gmix_cb (BonoboUIComponent *uic,
 		     gpointer           data,
 		     const gchar       *verbname)
 {
-	gnome_execute_shell (NULL, "gnome-volume-control");
+	GError *error = NULL;
+	
+	if (run_mixer_cmd)
+		g_spawn_command_line_async (run_mixer_cmd, &error);
+		
+	if (error) {
+		g_print ("%s \n", error->message);
+		g_error_free (error);
+	}
 }
 
 static void
@@ -690,24 +737,38 @@ mixer_about_cb (BonoboUIComponent *uic,
 		const gchar       *verbname)
 {
         static GtkWidget   *about     = NULL;
+        GdkPixbuf *pixbuf             = NULL;
+        gchar *file;
         static const gchar *authors[] = {
 		"Richard Hult <rhult@codefactory.se>",
                 NULL
         };
 
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
+	
         if (about != NULL) {
                 gtk_window_present (GTK_WINDOW (about));
                 return;
         }
+        
+        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-mixer-applet.png", TRUE, NULL);
+        pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+        g_free (file);
 
         about = gnome_about_new (_("Volume Control"), VERSION,
                                  _("(C) 2001 Richard Hult"),
                                  _("The volume control lets you set the volume level for your desktop."),
 				 authors,
-				 NULL,
-				 NULL,
-                                 NULL);
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+                                 pixbuf);
 
+	gtk_window_set_wmclass (GTK_WINDOW(about), "volume control", "Volume Control");
+	gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-mixer-applet.png");
         g_signal_connect (G_OBJECT (about), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
 	                  &about);
@@ -763,10 +824,32 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 		if (data->mute) {
 			setMixer (0);
 			mixer_update_image (data);
+		
+				
+			gtk_tooltips_set_tip (data->tooltips,
+					      data->applet,
+					      _(access_name_mute),
+					      NULL); 
+			if (gail_loaded) {
+				add_atk_namedesc (data->applet,
+						  _(access_name_mute),
+						  NULL);
+			}
 		}
 		else {
 			setMixer (data->vol);
 			mixer_update_image (data);
+			
+			
+			gtk_tooltips_set_tip (data->tooltips,
+					      data->applet,
+					      _(access_name),
+					      NULL); 
+			if (gail_loaded) {
+				add_atk_namedesc (data->applet,
+						  _(access_name),
+						  NULL);
+			}
 		}
 	}
 }
@@ -785,14 +868,37 @@ mixer_applet_create (PanelApplet *applet)
 {
 	MixerData         *data;
 	BonoboUIComponent *component;
+	const gchar *device;
+	gboolean retval;
 
 #ifdef OSS_API
-	openMixer("/dev/mixer");
+	/* /dev/sound/mixer for devfs */
+	device = "/dev/mixer";
+	retval = openMixer(device);
+	if (!retval) {
+		device = "/dev/sound/mixer";
+		retval = openMixer (device);
+	}
 #endif
 #ifdef SUN_API
-	openMixer("/dev/audioctl");
+	device = "/dev/audioctl";
+	retval = openMixer(device);
 #endif
 
+	if (!retval) {
+		GtkWidget *dialog;
+		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+						 ("Couldn't open mixer device %s\n"),
+						 device, NULL);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+	}
+
+ 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(GTK_WIDGET(applet)))) {
+		gail_loaded = TRUE;
+	}
+
 	data = g_new0 (MixerData, 1);
 
 	if (zero_pixbuf == NULL) {
@@ -803,6 +909,15 @@ mixer_applet_create (PanelApplet *applet)
 		mute_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_mute_xpm);
 	}
 	
+	/* Try to find some mixers - sdtaudiocontrol is on Solaris and is needed
+	** because gnome-volume-meter doesn't work */
+	if (run_mixer_cmd == NULL) 
+		run_mixer_cmd = g_find_program_in_path ("gnome-volume-meter");
+	if (run_mixer_cmd == NULL) 
+		run_mixer_cmd = g_find_program_in_path ("gmix");
+	if (run_mixer_cmd == NULL) 
+		run_mixer_cmd = g_find_program_in_path ("sdtaudiocontrol");
+	
 	data->frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (data->frame), GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (applet), data->frame);
@@ -811,22 +926,38 @@ mixer_applet_create (PanelApplet *applet)
 	gtk_container_add (GTK_CONTAINER (data->frame), data->image);
 
 	data->applet = GTK_WIDGET (applet);
-	
-	g_signal_connect (data->applet,
-			  "button-press-event",
-			  (GCallback) applet_button_press_event_cb,
-			  data);
+
+        data->tooltips = gtk_tooltips_new ();                                   
+        gtk_tooltips_set_tip (data->tooltips,
+			      data->applet,
+			      _(access_name),
+			      NULL);
+	if (gail_loaded) { 
+		add_atk_namedesc(GTK_WIDGET(data->applet),
+				 _(access_name),
+				 _("The volume control lets you set the volume level for your desktop"));
+	} 
 	
 	g_signal_connect (data->applet,
 			  "button-release-event",
 			  (GCallback) applet_button_release_event_cb,
 			  data);
 	
-        data->adj = GTK_ADJUSTMENT (
+	g_signal_connect (data->applet,
+			  "key-press-event",
+			  (GCallback) applet_key_press_event_cb,
+			  data);
+	
+	g_signal_connect (data->applet,
+			  "scroll-event",
+			  (GCallback) applet_scroll_event_cb,
+			  data);
+ 
+	data->adj = GTK_ADJUSTMENT (
 		gtk_adjustment_new (-50,
 				    -VOLUME_MAX,
 				    0.0, 
-				    VOLUME_MAX/100,
+				    VOLUME_MAX/20,
 				    VOLUME_MAX/10,
 				    0.0));
 
@@ -880,6 +1011,9 @@ mixer_applet_create (PanelApplet *applet)
 			  (GCallback) mixer_ui_component_event,
 			  data);
 
+	if (run_mixer_cmd == NULL)
+		bonobo_ui_component_rm (component, "/popups/popup/RunMixer", NULL);
+
 	applet_change_orient_cb (GTK_WIDGET (applet),
 				 panel_applet_get_orient (applet),
 				 data);
@@ -909,3 +1043,13 @@ PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MixerApplet_Factory",
 			     "0",
 			     mixer_applet_factory,
 			     NULL)
+ 
+/* Accessible name and description */ 
+void 
+add_atk_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc) 
+{ 
+	AtkObject *atk_widget;
+	atk_widget = gtk_widget_get_accessible(widget);
+	atk_object_set_name(atk_widget, name);
+	atk_object_set_description(atk_widget, desc);
+}                                                                               
