@@ -15,6 +15,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libbonobo.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
@@ -30,7 +34,7 @@
 
 static const gchar *windows_menu_xml =
 	"    <placeholder name=\"ChildItem\">\n"
-	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove Windows\"\n"
+	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove Windows Menu\"\n"
 	"                  pixtype=\"stock\" pixname=\"gtk-close\"/>\n"
 	"        <separator/>" "    </placeholder>";
 
@@ -446,8 +450,8 @@ set_icon_from_window (GtkImageMenuItem *menuitem, WnckWindow *window, gint icon_
 gchar *
 panel_menu_windows_save_config (PanelMenuEntry *entry)
 {
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->type == PANEL_MENU_TYPE_WINDOWS);
+	g_return_val_if_fail (entry != NULL, NULL);
+	g_return_val_if_fail (entry->type == PANEL_MENU_TYPE_WINDOWS, NULL);
 
 	return g_strdup ("windows");
 }
