@@ -126,7 +126,7 @@ static const char applet_menu_xml[] =
 	"   <placeholder name=\"ChildMerge\"/>\n"
 	"   <menuitem name=\"Add\" verb=\"Add\" _label=\"Add...\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-add\"/>\n"
-	"   <menuitem name=\"Properties Item\" verb=\"Properties\" _label=\"Menu Bar Preferences...\"\n"
+	"   <menuitem name=\"Properties Item\" verb=\"Properties\" _label=\"Preferences...\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
 	"   <menuitem name=\"Help Item\" verb=\"Help\" _label=\"Help\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
@@ -665,6 +665,12 @@ applet_about_cb (BonoboUIComponent *uic, PanelMenu *panel_menu,
 		NULL
 	};
 
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
+
 	if (about != NULL) {
 		gtk_widget_show (about);
 		gtk_window_present (GTK_WINDOW (about));
@@ -681,11 +687,12 @@ applet_about_cb (BonoboUIComponent *uic, PanelMenu *panel_menu,
 		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	}
 
-	about = gnome_about_new (_("PanelMenu Applet"), "0.0.1",
+	about = gnome_about_new (_("Menu Bar"), "0.0.1",
 				 _("(c) 2001 Chris Phelps"),
-				 _("The Panel Menu Applet allows you to display customized menubars on your panels."),
-				 authors, NULL,	/* documenters */
-				 NULL,	/* translator_credits */
+				 _("The Menu Bar allows you to display customized menubars on your panels."),
+				 authors,
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 
 	gtk_window_set_wmclass (GTK_WINDOW (about), "panel-menu", "PanelMenu");
